import React, { Fragment } from 'react'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { Checkbox, ValidatedField } from '@pubsweet/ui'
import { FormItems } from 'pubsweet-components-faraday/src/components'

const { Row, Title, Subtitle, DefaultText } = FormItems

const StepOne = () => (
  <Fragment>
    <Title>1. Pre-Submission Checklist</Title>
    <Subtitle>
      Before moving forward make sure you have all the required files prepared
      and the items on the list below reviewed.
    </Subtitle>
    <Row justify="flex-start">
      <DefaultText>
        I have the email addresses of all the co-authors of the manuscript.
      </DefaultText>
    </Row>
    <Row justify="flex-start">
      <DefaultText>
        I have the manuscript file in Microsoft Word or Adobe PDF format with
        the tables and figures integrated in the manuscript body.
      </DefaultText>
    </Row>
    <Row justify="flex-start">
      <DefaultText>
        I have the electronic files of any supplementary materials (e.g.,
        datasest, images, audio, video) that I want to submit with the
        manuscript.
      </DefaultText>
    </Row>
    <Row justify="flex-start">
      <DefaultText>
        I am aware that accepted manuscripts are subject to{' '}
        <a
          data-test="apc-anchor"
          href="https://www.hindawi.com/apc/"
          rel="noopener noreferrer"
          target="_blank"
        >
          Article Processing Charges
        </a>.
      </DefaultText>
    </Row>
    <Row justify="flex-start">
      <DefaultText>
        I am aware that an{' '}
        <a
          data-test="orcid-anchor"
          href="https://orcid.org/"
          rel="noopener noreferrer"
          target="_blank"
        >
          ORCID ID
        </a>{' '}
        is required for the corresponding author before the article can be
        published (if accepted). The ORCID ID should be added via your user
        account.
      </DefaultText>
    </Row>
    <Row justify="flex-start">
      <DefaultText>
        I am aware that if my submission is covered by an{' '}
        <a
          data-test="membership-anchor"
          href="https://www.hindawi.com/members/"
          rel="noopener noreferrer"
          target="_blank"
        >
          institutional membership
        </a>, Hindawi will share details of the manuscript with the
        administrator of the membership.
      </DefaultText>
    </Row>
    <Row justify="flex-start">
      <DefaultText>
        I am aware of the Hindawi article processing charges tax of $1000.
      </DefaultText>
    </Row>
    <Row justify="center">
      <ValidatedField component={CustomCheckbox} name="declarations.agree" />
    </Row>
  </Fragment>
)

const CustomCheckbox = input => (
  <RootCheckbox data-test="agree-checkbox">
    <Checkbox
      checked={input.value}
      {...input}
      label={`I've reviewed and understood all the above items.`}
    />
  </RootCheckbox>
)

export default StepOne

// #region styled-components
const RootCheckbox = styled.div.attrs({
  className: 'custom-checkbox',
})`
  & label {
    margin-bottom: calc(${th('gridUnit')} / 2);
    & span {
      color: ${th('colorText')};
      font-family: ${th('fontReading')};
      font-size: ${th('fontSizeBase')};
    }
  }
`
// #endregion
